Module rust_socketio::client
source · [−]Expand description
Defines client only structs
Structs
A socket which handles communication with the server. It’s initialized with
a specific address as well as an optional namespace to connect to. If None
is given the server will connect to the default namespace "/".
A builder class for a socket.io socket. This handles setting up the client and
configuring the callback, the namespace and metadata of the socket. If no
namespace is specified, the default namespace / is taken. The connect method
acts the build method and returns a connected Client.
Enums
Flavor of Engine.IO transport.